@@ -6,11 +6,14 @@
 #' @param unknownpts sp object (SpatialPointsDataFrame or SpatialPolygonsDataFrame); 
 #' this is the set of unknown units for which the function computes the estimates. 
 #' Not used when \code{resolution} is set up. (optional)
-#' @param matdist matrix; a distance matrix. Row names match the first 
-#' column of the \code{knownpts} object dataframe. Column names match the first column 
-#' of the \code{unknownpts} object dataframe. (optional)
-#' @param varname character; name of the variable in the \code{knownpts} dataframe from which values are computed.
-#' Quantitative variable with no negative values. 
+#' @param matdist matrix; distance matrix between known observations and unknown 
+#' units for which the function computes the estimates. Row names match the row 
+#' names of \code{knownpts} and column names match the row names of 
+#' \code{unknownpts}. \code{matdist} can contain any distance metric (time 
+#' distance or euclidean distance for example). If \code{matdist} is NULL, Great 
+#' Circle distances are used (with \code{\link{CreateDistMatrix}}).(optional)
+#' @param varname character; name of the variable in the \code{knownpts} dataframe 
+#' from which values are computed. Quantitative variable with no negative values. 
 #' @param typefct character; spatial interaction function. Options are "pareto" 
 #' (means power law) or "exponential".
 #' If "pareto" the interaction is defined as: (1 + alpha * mDistance) ^ (-beta).
@@ -23,34 +26,31 @@
 #' @param beta numeric; impedance factor for the spatial interaction function.  
 #' @param resolution numeric; resolution of the output SpatialPointsDataFrame
 #'  (in map units). 
-#' @param longlat logical; euclidean distance (FALSE, default) or Great Circle distance (TRUE).
-#' If TRUE inputs are expected in the WGS84 reference system.
 #' @param mask sp object; the spatial extent of this object is used to 
 #' create the regularly spaced SpatialPointsDataFrame output. (optional)
-#' @details If \code{unknownpts} is NULL then \code{resolution} must be used. 
-#' @return SpatialPointsDataFrame with the computed catchment areas in a new field nammed \code{OUTPUT}.
-#' Values match the row names of \code{knownpts}
-#' @seealso \link{reilly}, \link{rasterReilly}, \link{plotReilly}, \link{CreateGrid}, \link{CreateDistMatrix}.
+#' @return SpatialPointsDataFrame with the computed catchment areas in a new 
+#' field named \code{OUTPUT}. Values match the row names of \code{knownpts}.
+#' @seealso \link{reilly}, \link{rasterReilly}, \link{plotReilly}, \link{CreateGrid}, 
+#' \link{CreateDistMatrix}.
 #' @examples 
 #' # Create a SpatialPointsDataFrame grid of spatMask extent and 200 meters 
 #' # resolution
 #' data(spatData)
 #' mygrid <- CreateGrid(w = spatMask, resolution = 200)
 #' # Create a distance matrix between known points (spatPts) and mygrid
-#' mymat <- CreateDistMatrix(knownpts = spatPts, unknownpts = mygrid, 
-#'                           longlat = FALSE)
+#' mymat <- CreateDistMatrix(knownpts = spatPts, unknownpts = mygrid)
 #' # Compute Reilly catchment areas from known points (spatPts) on a given 
 #' # grid (mygrid) using a given distance matrix (mymat)
 #' myreilly2 <- reilly(knownpts = spatPts, unknownpts = mygrid, 
 #'                matdist = mymat, varname = "Capacite", 
 #'                typefct = "exponential", span = 1250, 
-#'                beta = 3, longlat = FALSE, mask = spatMask)
+#'                beta = 3, mask = spatMask)
 #' row.names(spatPts) <- spatPts$CodHop
 #' # Compute Reilly catchment areas from known points (spatPts) on a 
 #' # grid defined by its resolution
 #' myreilly <- reilly(knownpts = spatPts, varname = "Capacite", 
 #'                 typefct = "exponential", span = 1250, beta = 3, 
-#'                 resolution = 200, longlat = FALSE, mask = spatMask)
+#'                 resolution = 200, mask = spatMask)
 #' # The function output a SpatialPointsDataFrame
 #' class(myreilly)
 #' # The OUTPUT field values match knownpts row names
@@ -66,8 +66,7 @@ reilly <- function(knownpts,
                    typefct = "exponential", 
                    span,
                    beta,
-                   resolution = 2000,
-                   longlat = FALSE, 
+                   resolution = NULL,
                    mask = NULL)
 {
   TestSp(knownpts)
@@ -81,14 +80,12 @@ reilly <- function(knownpts,
       matdist <- UseDistMatrix(matdist =matdist, knownpts = knownpts, 
                                unknownpts =  unknownpts) 
     }else{
-      matdist <- CreateDistMatrix(knownpts = knownpts, unknownpts = unknownpts, 
-                                  longlat = longlat) 
+      matdist <- CreateDistMatrix(knownpts = knownpts, unknownpts = unknownpts) 
     }
   } else {
     unknownpts <- CreateGrid(w = if(is.null(mask)){knownpts} else {mask}, 
                              resolution = resolution) 
-    matdist <- CreateDistMatrix(knownpts = knownpts, unknownpts = unknownpts, 
-                                longlat = longlat) 
+    matdist <- CreateDistMatrix(knownpts = knownpts, unknownpts = unknownpts) 
   }
   
   
@@ -109,12 +106,14 @@ reilly <- function(knownpts,
 #' @description This function creates a raster from a regularly spaced 
 #' Reilly SpatialPointsDataFrame (output of the \code{\link{reilly}} function). 
 #' @param x sp object (SpatialPointsDataFrame); output of the \code{reilly} function.
-#' @param mask sp object (SpatialPolygonsDataFrame); this object is used to clip the raster. (optional)
+#' @param mask sp object (SpatialPolygonsDataFrame); this object is used to clip 
+#' the raster. (optional)
 #' @return Raster of catchment areas values.
 #' The raster uses a RAT (\code{\link{ratify}}) that contains the 
 #' correspondance between raster values and catchement areas values. Use \code{
 #' unique(levels(rasterName)[[1]])} to see the correpondance table.
-#' @seealso \link{reilly}, \link{rasterReilly}, \link{plotReilly}, \link{CreateGrid}, \link{CreateDistMatrix}.
+#' @seealso \link{reilly}, \link{rasterReilly}, \link{plotReilly}, \link{CreateGrid}, 
+#' \link{CreateDistMatrix}.
 #' @examples 
 #' data(spatData)
 #' row.names(spatPts) <- spatPts$CodHop
@@ -122,7 +121,7 @@ reilly <- function(knownpts,
 #' # grid defined by its resolution
 #' myreilly <- reilly(knownpts = spatPts, varname = "Capacite",
 #'                    typefct = "exponential", span = 750, beta = 2,
-#'                    resolution = 50, longlat = FALSE, mask = spatMask)
+#'                    resolution = 100, mask = spatMask)
 #' # Create a raster of reilly values
 #' myreillyraster <- rasterReilly(x = myreilly, mask = spatMask)
 #' plot(myreillyraster, col = rainbow(18))
@@ -149,12 +148,15 @@ rasterReilly <- function(x ,mask = NULL){
 
 #' @title Plot a Reilly Raster
 #' @name plotReilly
-#' @description This function plots the raster produced by the \code{\link{rasterReilly}} function.
+#' @description This function plots the raster produced by the 
+#' \code{\link{rasterReilly}} function.
 #' @param x raster; output of the \code{\link{rasterReilly}} function.
-#' @param add logical; if TRUE the raster is added to the current plot, if FALSE the raster is displayed in a new plot.
+#' @param add logical; if TRUE the raster is added to the current plot, if FALSE 
+#' the raster is displayed in a new plot.
 #' @param col function; color ramp function, such as \code{\link{colorRampPalette}}.
 #' @details Display the raster nicely.
-#' @seealso \link{reilly}, \link{rasterReilly}, \link{plotReilly}, \link{CreateGrid}, \link{CreateDistMatrix}.
+#' @seealso \link{reilly}, \link{rasterReilly}, \link{plotReilly}, \link{CreateGrid}, 
+#' \link{CreateDistMatrix}.
 #' @examples 
 #' data(spatData)
 #' row.names(spatPts) <- spatPts$CodHop
@@ -162,7 +164,7 @@ rasterReilly <- function(x ,mask = NULL){
 #' # grid defined by its resolution
 #' myreilly <- reilly(knownpts = spatPts, varname = "Capacite",
 #'                    typefct = "exponential", span = 750, beta = 2,
-#'                    resolution = 50, longlat = FALSE, mask = spatMask)
+#'                    resolution = 100, mask = spatMask)
 #' # Create a raster of reilly values
 #' myreillyraster <- rasterReilly(x = myreilly, mask = spatMask)
 #' # Plot the raster nicely
